@@ -1,5 +1,5 @@
 loglik_joint <-
-function(alpha,beta,theta,delta,x,y,R,S,family,exposure=rep(1,length(y)),negative=TRUE){
+function(alpha,beta,theta,delta,x,y,R,S,family,exposure=rep(1,length(y)),negative=TRUE,zt=TRUE){
     p<-ncol(R)
     q<-ncol(S)
     n<-nrow(R)
@@ -7,7 +7,7 @@ function(alpha,beta,theta,delta,x,y,R,S,family,exposure=rep(1,length(y)),negativ
 	mu<-as.vector(exp(R%*%alpha))   
 	#if (any(lambda<10^(-10)) | any(mu<10^(-10))) {ll<-(-10^(100))}
 	#else{
-	dummy<-log(density_joint(x,y,mu,delta,lambda,theta,family))
+	dummy<-log(density_joint(x,y,mu,delta,lambda,theta,family,zt))
     #if ((any(is.na(dummy)))| (any(dummy==-Inf))) {ll<-(-10^(100))}
 	#else{
     		ll<-sum(dummy)
